"""Top-level package for deluge_cmd."""

__author__ = """Chris B Chamberlain"""
__email__ = 'chrisbc@artisan.co.nz'
__version__ = '1.0.0'

from .config import API_KEY, API_URL, S3_URL
from .toshi_file import ToshiFile
